@@ -109,6 +109,7 @@ DICOMImage::DICOMImage(const char *path, bool verbose, bool haveNumSlices) :
 			&& GetImageNumber()
 			&& GetACQNumber()
 			&& GetACQEchoNumber()
+			&& GetACQEchoTime()
 			&& GetACQMatrix()
 			&& GetD3()
 			&& GetSliceThickness()
@@ -486,13 +487,7 @@ bool DICOMImage::GetACQDescription()
 	   strn = NULL;
    }
 
-   if (GetData(DCM_ACQECHOTIME, &strn) == 0)
-   {
-	  error_ = false;
-	  COND_PopCondition(TRUE);				// Clear error from stack
-   }
-   else
-	   acqDescription_ += string("/TE=") + strn;
+   acqDescription_ += string("/TE=") + to_string(acqEchoTime_);
 
    if ( strn != NULL )
    {
@@ -903,6 +898,41 @@ bool DICOMImage::GetACQEchoNumber()
    return true;
 }
 
+//////////////////////////////////////////////////////////////////////////////
+///
+/// Purpose: Get the value for the acquisition echo time (0018, 0081)
+///   
+/// @param   NONE 
+///   
+/// @return  false if error
+///   
+/// Notes: This applies to field maps
+///
+//////////////////////////////////////////////////////////////////////////////
+
+bool DICOMImage::GetACQEchoTime()
+{
+   // The number is really stored as a string
+  
+   char *strn = NULL;
+  
+   if (GetData(DCM_ACQECHOTIME, &strn) == 0)
+   {
+	  error_ = false;
+	  COND_PopCondition(TRUE);				// Clear error from stack
+	  acqEchoTime_ = 0.0;
+   }
+   else
+   {
+	   // Convert string to numerical value
+
+	   acqEchoTime_ = atof(strn);
+   }
+   
+   if (strn != NULL) delete [] strn;
+   return true;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 ///
 /// Purpose: Get the value for the acquisition matrix (0018, 1310)
