@@ -1,4 +1,4 @@
-#define VERSION "2.32.1"
+#define VERSION "2.33.1"
 
 //****************************************************************************
 //
@@ -553,29 +553,22 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 				// We need to fix this list. Use echo number to augment list size.
 
 				IMAGELIST *timePointList = si.imageMap[fixIter->first];
-				int baseAcqNum = fixIter->first;
+				IMAGEMAP splitMap;
+				si.minAcqNum = si.maxAcqNum;
 				
-				for ( IMAGELIST::iterator timeIter = timePointList->begin(); timeIter != timePointList->end(); )
+				for ( IMAGELIST::iterator timeIter = timePointList->begin(); timeIter != timePointList->end(); ++timeIter)
 				{
-					// Acquisition numbers start from 1, while echo start from 0
 					int thisAcqNum = timeIter->ACQEchoNumber();
-					
-					if ( ++thisAcqNum != baseAcqNum )
+					IMAGELIST *timePoint = splitMap[thisAcqNum];
+					if ( timePoint == NULL )
 					{
-						// This has to go in a new list, see if we need to create it.
-
-						IMAGELIST *timePoint = si.imageMap[thisAcqNum];
-						if ( timePoint == NULL )
-						{
-							si.imageMap[thisAcqNum] = timePoint = new IMAGELIST;
-							if ( thisAcqNum > si.maxAcqNum ) si.maxAcqNum = thisAcqNum;
-						}
-						timePoint->push_back(*timeIter);
-						timePointList->erase(timeIter++);
+						splitMap[thisAcqNum] = timePoint = new IMAGELIST;
+						if ( thisAcqNum > si.maxAcqNum ) si.maxAcqNum = thisAcqNum;
+						if ( thisAcqNum < si.minAcqNum ) si.minAcqNum = thisAcqNum;
 					}
-					else
-						++timeIter;
+					timePoint->push_back(*timeIter);
 				}
+				si.imageMap.swap(splitMap);
 				series->second = si;
 			}
 		}
